@@ -2,9 +2,9 @@
 # flake8: noqa
 __author__ = 'Nick Ficano'
 __email__ = 'nficano@gmail.com'
-__version__ = '0.1.11'
+__version__ = '0.6.0'
 
-from .aws_lambda import deploy, invoke, init
+from .aws_lambda import deploy, invoke, init, build, cleanup_old_versions
 
 # Set default logging handler to avoid "No handler found" warnings.
 import logging
